@@ -1,14 +1,14 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* petri ---  */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)petri.c	5.04 2002/07/19 xlockmore";
 
 #endif
 
 /* petri, simulate mold in a petri dish. v2.7
  * by Dan Bornstein, danfuzz@milk.com
- * with help from Jamie Zawinski, jwz@jwz.org
+ * with help from Jamie Zawinski, jwz AT jwz.org
  * Copyright (c) 1992-1999 Dan Bornstein.
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
@@ -68,26 +68,27 @@ static const char sccsid[] = "@(#)petri.c	5.04 2002/07/19 xlockmore";
  *              -anychan 0.3 -delay 4000
  *
  * Revision History:
- * 22 Jul-2002: xlockmore version by Jouk Jansen <joukj@hrem.stm.tudelft.nl>
+ * 22 Jul-2002: xlockmore version by Jouk Jansen <joukj AT hrem.nano.tudelft.nl>
  */
 
 #ifdef STANDALONE
 #define MODE_petri
-#define PROGCLASS "Petri"
-#define HACK_INIT init_petri
-#define HACK_DRAW draw_petri
-#define petri_opts xlockmore_opts
 #define DEFAULTS "*delay: 10000 \n" \
- "*size: 4 \n" \
- "*ncolors: 8 \n" \
- "*fullrandom: True \n" \
- "*verbose: False \n"
+	"*size: 4 \n" \
+	"*ncolors: 8 \n" \
+	"*fullrandom: True \n" \
+	"*verbose: False \n" \
+
+# define free_petri 0
+# define reshape_petri 0
+# define petri_handle_event 0
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #include "color.h"
-#include "automata.h"
+#define DO_STIPPLE
 #endif /* STANDALONE */
+#include "automata.h"
 
 #ifdef MODE_petri
 
@@ -179,7 +180,7 @@ static OptionStruct desc[] =
    {(char *) "-minorchan float", (char *) "The chance on a minor cell birth"}
 };
 
-ModeSpecOpt petri_opts =
+ENTRYPOINT ModeSpecOpt petri_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
@@ -208,7 +209,7 @@ typedef struct cell_s
 #define PETRIBITS(n,w,h)\
   if ((sp->pixmaps[sp->init_bits]=\
   XCreatePixmapFromBitmapData(display,window,(char *)n,w,h,1,0,1))==None){\
-  free_petri(display,sp); return False;} else {sp->init_bits++;}
+  free_petri_screen(display,sp); return False;} else {sp->init_bits++;}
 
 #define cell_x(c) (((c) - sp->arr) % sp->arr_width)
 #define cell_y(c) (((c) - sp->arr) / sp->arr_width)
@@ -257,10 +258,13 @@ static int random_life_value (petristruct *sp)
 }
 
 static void
-free_petri(Display *display, petristruct *sp)
+free_petri_screen(Display *display, petristruct *sp)
 {
     int n, shade;
 
+    if (sp == NULL) {
+        return;
+    }
     if (sp->coloredGCs != NULL) {
 	for (n = 0; n < sp->count*2; n++)
 		if (sp->coloredGCs[n] != None)
@@ -288,6 +292,7 @@ free_petri(Display *display, petristruct *sp)
 		free(sp->tail);
 		sp->tail = (cell *) NULL;
     }
+    sp = NULL;
 }
 
 static int setup_random_colormap (ModeInfo * mi)
@@ -297,12 +302,15 @@ static int setup_random_colormap (ModeInfo * mi)
    int ncolors = sp->count - 1;
    int n;
    XColor *colors = (XColor *) NULL;
+#ifdef STANDALONE
+  Screen *screen = MI_SCREENPTR(mi);
+#endif
    Display    *display = MI_DISPLAY(mi);
    Window      window = MI_WINDOW(mi);
 
     colors = (XColor *) calloc (sizeof(*colors), sp->count*2);
     if (colors == NULL) {
-	free_petri(display, sp);
+	free_petri_screen(display, sp);
         return False;
     }
     colors[0].pixel = MI_BLACK_PIXEL(mi);
@@ -312,12 +320,15 @@ static int setup_random_colormap (ModeInfo * mi)
     } else
         make_random_colormap (
 #ifdef STANDALONE
-			  display , window ,
+            screen, MI_VISUAL(mi),
+            sp->cmap, colors + 1, &ncolors,
+            True, True, 0, True
 #else
-			  mi ,
+            mi,
+            sp->cmap, colors + 1, &ncolors,
+            True, True, 0
 #endif
-			  sp->cmap ,
-			  colors+1, &ncolors, True, True, 0);
+            );
     if (ncolors < 1) {
 	sp->mono = True;
     }
@@ -336,7 +347,7 @@ static int setup_random_colormap (ModeInfo * mi)
 	    gcv.fill_style = FillOpaqueStippled;
 	    if ((sp->stippledGC = XCreateGC(display, window, GCFillStyle,
 		   &gcv)) == None) {
-		free_petri(display, sp);
+		free_petri_screen(display, sp);
 		return False;
 	    }
 	}
@@ -376,7 +387,10 @@ static int setup_random_colormap (ModeInfo * mi)
         XGCValues gcv;
 
 #ifdef WIN32
-	gcv.foreground = MI_PIXEL(mi, NRAND(MI_NPIXELS(mi)));
+        if (n == 0)
+		gcv.foreground = MI_BLACK_PIXEL(mi);
+	else
+		gcv.foreground = MI_PIXEL(mi, NRAND(MI_NPIXELS(mi)));
 #else
 	gcv.foreground = colors[n].pixel;
 #endif
@@ -410,7 +424,7 @@ static int setup_original_colormap (ModeInfo * mi)
 	    gcv.fill_style = FillOpaqueStippled;
 	    if ((sp->stippledGC = XCreateGC(display, window, GCFillStyle,
 		   &gcv)) == None) {
-		free_petri(display, sp);
+		free_petri_screen(display, sp);
 		return False;
 	    }
 	}
@@ -425,7 +439,7 @@ static int setup_original_colormap (ModeInfo * mi)
 
     colors = (XColor *) calloc (sizeof(*colors), sp->count*2);
     if (colors == NULL) {
-	free_petri(display, sp);
+	free_petri_screen(display, sp);
         return False;
     }
     colors[0].pixel = MI_BLACK_PIXEL(mi);
@@ -512,7 +526,7 @@ static int setup_display (ModeInfo * mi)
           {
             (void) fprintf (stderr,
 		     "petri: invalid memThrottle \"%s\" (try \"10M\")\n", s);
-            free_petri(display, sp);
+            free_petri_screen(display, sp);
 	    return False;
           }
 
@@ -541,7 +555,7 @@ static int setup_display (ModeInfo * mi)
 
     sp->coloredGCs = (GC *) calloc (sizeof(GC), sp->count * 2);
     if (sp->coloredGCs == NULL) {
-	free_petri(display, sp);
+	free_petri_screen(display, sp);
         return False;
     }
 
@@ -806,7 +820,7 @@ static int setup_arr (ModeInfo * mi)
       {
         (void) fprintf (stderr, "petri: out of memory allocating %dx%d grid\n",
                  sp->arr_width, sp->arr_height);
-	free_petri(display, sp);
+	free_petri_screen(display, sp);
         return False;
       }
 
@@ -831,7 +845,7 @@ static int setup_arr (ModeInfo * mi)
       {
         (void) fprintf (stderr, "petri: out of memory allocating %dx%d grid\n",
                  sp->arr_width, sp->arr_height);
-	free_petri(display, sp);
+	free_petri_screen(display, sp);
         return False;
     }
     }
@@ -843,7 +857,7 @@ static int setup_arr (ModeInfo * mi)
       {
         (void) fprintf (stderr, "petri: out of memory allocating %dx%d grid\n",
                  sp->arr_width, sp->arr_height);
-	free_petri(display, sp);
+	free_petri_screen(display, sp);
         return False;
     }
     }
@@ -947,7 +961,8 @@ static int randblip (ModeInfo * mi , int doit)
     return True;
 }
 
-void draw_petri (ModeInfo * mi)
+ENTRYPOINT void
+draw_petri (ModeInfo * mi)
 {
    petristruct *sp = &petries[MI_SCREEN(mi)];
     cell *a;
@@ -1028,7 +1043,7 @@ void draw_petri (ModeInfo * mi)
     }
 }
 
-void
+ENTRYPOINT void
 init_petri(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
@@ -1050,13 +1065,9 @@ init_petri(ModeInfo * mi)
      }
 
 /* initialize */
-	if (petries == NULL) {
-		if ((petries = (petristruct *) calloc(MI_NUM_SCREENS(mi),
-					   sizeof (petristruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, petries);
 	sp = &petries[MI_SCREEN(mi)];
-	free_petri(display, sp);
+	free_petri_screen(display, sp);
         sp->redrawing = 0;
         if (!setup_display(mi))
 	   return;
@@ -1066,20 +1077,21 @@ init_petri(ModeInfo * mi)
     (void) randblip (mi , 1);
 }
 
-void
+ENTRYPOINT void
 release_petri(ModeInfo * mi)
 {
    if (petries != NULL) {
       int screen;
 
       for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-	free_petri(MI_DISPLAY(mi), &petries[screen]);
+	free_petri_screen(MI_DISPLAY(mi), &petries[screen]);
       free(petries);
       petries = (petristruct *) NULL;
    }
 }
 
-void
+#ifndef STANDALONE
+ENTRYPOINT void
 refresh_petri(ModeInfo * mi)
 {
   petristruct *sp;
@@ -1091,4 +1103,8 @@ refresh_petri(ModeInfo * mi)
   sp->redrawing = 1;
   sp->redrawpos = 0;
 }
+#endif
+
+XSCREENSAVER_MODULE ("Petri", petri)
+
 #endif /* MODE_petri */
