@@ -1,9 +1,8 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* pyro --- fireworks */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)pyro.c	5.00 2000/11/01 xlockmore";
-
 #endif
 
 /*-
@@ -23,7 +22,7 @@ static const char sccsid[] = "@(#)pyro.c	5.00 2000/11/01 xlockmore";
  *
  * Revision History:
  * 01-Nov-2000: Allocation checks
- * 15-May-1997: jwz@jwz.org: turned into a standalone program.
+ * 15-May-1997: jwz AT jwz.org: turned into a standalone program.
  * 05-Sep-1996: Added 3d support Henrik Theiling <theiling@coli.uni-sb.de>
  * 16-Mar-1991: Written, received from David Brooks <brooks@osf.org>
  */
@@ -34,34 +33,34 @@ static const char sccsid[] = "@(#)pyro.c	5.00 2000/11/01 xlockmore";
  * overcomes the rocket's impulse) and explode as the rocket's main fuse
  * gives out (we could add a ballistic stage, maybe).  The individual
  * stars fan out from the rocket, and they decelerate less quickly.
- * That's called bouyancy, but really it's again a visual preference.
+ * That's called buoyancy, but really it's again a visual preference.
  */
 
 #ifdef STANDALONE
 #define MODE_pyro
-#define PROGCLASS "Pyro"
-#define HACK_INIT init_pyro
-#define HACK_DRAW draw_pyro
-#define pyro_opts xlockmore_opts
 #define DEFAULTS "*delay: 15000 \n" \
- "*count: 100 \n" \
- "*size: -3 \n" \
- "*ncolors: 200 \n" \
- "*use3d: False \n" \
- "*delta3d: 1.5 \n" \
- "*right3d: red \n" \
- "*left3d: blue \n" \
- "*both3d: magenta \n" \
- "*none3d: black \n"
-#define UNIFORM_COLORS
-#include "xlockmore.h"		/* in xscreensaver distribution */
+	"*count: 100 \n" \
+	"*size: -3 \n" \
+	"*ncolors: 200 \n" \
+	"*use3d: False \n" \
+	"*delta3d: 1.5 \n" \
+	"*right3d: red \n" \
+	"*left3d: blue \n" \
+	"*both3d: magenta \n" \
+	"*none3d: black \n" \
+
+# define free_pyro 0
+# define reshape_pyro 0
+# define pyro_handle_event 0
+# define UNIFORM_COLORS
+# include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
-#include "xlock.h"		/* in xlockmore distribution */
+# include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
 #ifdef MODE_pyro
 
-ModeSpecOpt pyro_opts =
+ENTRYPOINT ModeSpecOpt pyro_opts =
 {0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
@@ -73,7 +72,7 @@ ModStruct   pyro_description =
 
 #endif
 
-#define ORANGE (MI_NPIXELS(mi) / 16)
+#define ORANGE (5 * MI_NPIXELS(mi) / 64)
 
 #define MINROCKETS 1
 #define MINSIZE 1
@@ -115,7 +114,7 @@ ModStruct   pyro_description =
 #define FUSILLEN 100		/* Length of fusillade, in ignitions */
 
 #define SVELFACTOR 0.1		/* Max star velocity / yvel */
-#define BOUYANCY 0.2		/* Reduction in grav deceleration for stars */
+#define BUOYANCY 0.2		/* Reduction in grav deceleration for stars */
 #define MAXSTARS 150		/* Number of stars issued from a shell */
 #define MINSTARS 50
 #define MINSFUSE 50		/* Range of fuse lengths for stars */
@@ -459,7 +458,19 @@ burst(ModeInfo * mi, pyrostruct * pp, rocket * rp)
 	}
 }
 
-void
+static void
+free_pyro_screen(pyrostruct * pp)
+{
+	if (pp == NULL) {
+		return;
+	}
+	if (pp->rockq != NULL) {
+		free(pp->rockq);
+	}
+	pp = NULL;
+}
+
+ENTRYPOINT void
 init_pyro(ModeInfo * mi)
 {
 	int         rockn, starn;
@@ -467,11 +478,7 @@ init_pyro(ModeInfo * mi)
 	rocket     *rp;
 	pyrostruct *pp;
 
-	if (pyros == NULL) {
-		if ((pyros = (pyrostruct *) calloc(MI_NUM_SCREENS(mi),
-					       sizeof (pyrostruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, pyros);
 	pp = &pyros[MI_SCREEN(mi)];
 
 	pp->width = MI_WIDTH(mi);
@@ -541,7 +548,7 @@ init_pyro(ModeInfo * mi)
 	}
 	pp->maxsvel = pp->minvely * SVELFACTOR;
 	pp->rockdecel = (float) (pp->height) * GRAVFACTOR;
-	pp->stardecel = pp->rockdecel * BOUYANCY;
+	pp->stardecel = pp->rockdecel * BUOYANCY;
 	if (MI_IS_INSTALL(mi) && MI_IS_USE3D(mi)) {
 		MI_CLEARWINDOWCOLOR(mi, MI_NONE_COLOR(mi));
 	} else {
@@ -550,7 +557,7 @@ init_pyro(ModeInfo * mi)
 }
 
 /* ARGSUSED */
-void
+ENTRYPOINT void
 draw_pyro(ModeInfo * mi)
 {
 	rocket     *rp;
@@ -586,25 +593,21 @@ draw_pyro(ModeInfo * mi)
 	}
 }
 
-void
+ENTRYPOINT void
 release_pyro(ModeInfo * mi)
 {
 	if (pyros != NULL) {
 		int         screen;
 
-		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
-			pyrostruct *pp = &pyros[screen];
-
-			if (pp->rockq != NULL) {
-				free(pp->rockq);
-			}
-		}
+		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
+			free_pyro_screen(&pyros[screen]);
 		free(pyros);
 		pyros = (pyrostruct *) NULL;
 	}
 }
 
-void
+#ifndef STANDALONE
+ENTRYPOINT void
 refresh_pyro(ModeInfo * mi)
 {
 	if (MI_IS_INSTALL(mi) && MI_IS_USE3D(mi)) {
@@ -613,5 +616,8 @@ refresh_pyro(ModeInfo * mi)
 		MI_CLEARWINDOW(mi);
 	}
 }
+#endif
+
+XSCREENSAVER_MODULE ("Pyro", pyro)
 
 #endif /* MODE_pyro */
