@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* wire --- logical circuits based on simple state-changes (wireworld) */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)wire.c	5.24 2007/01/18 xlockmore";
 
 #endif
@@ -88,19 +88,19 @@ static const char sccsid[] = "@(#)wire.c	5.24 2007/01/18 xlockmore";
 
 #ifdef STANDALONE
 #define MODE_wire
-#define PROGCLASS "Wire"
-#define HACK_INIT init_wire
-#define HACK_DRAW draw_wire
-#define wire_opts xlockmore_opts
 #define DEFAULTS "*delay: 500000 \n" \
- "*count: 1000 \n" \
- "*cycles: 150 \n" \
- "*size: -8 \n" \
- "*ncolors: 64 \n" \
- "*neighbors: 0 \n"
+	"*count: 1000 \n" \
+	"*cycles: 150 \n" \
+	"*size: -8 \n" \
+	"*ncolors: 64 \n" \
+
+# define free_wire 0
+# define reshape_wire 0
+# define wire_handle_event 0
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
+#define DO_STIPPLE
 #endif /* STANDALONE */
 #include "automata.h"
 
@@ -133,7 +133,7 @@ static OptionStruct desc[] =
 	{(char *) "-/+vertical", (char *) "change orientation for hexagons and triangles"}
 };
 
-ModeSpecOpt wire_opts =
+ENTRYPOINT ModeSpecOpt wire_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
@@ -148,7 +148,7 @@ ModStruct   wire_description =
 #define WIREBITS(n,w,h)\
   if ((wp->pixmaps[wp->init_bits]=\
   XCreatePixmapFromBitmapData(display,window,(char *)n,w,h,1,0,1))==None){\
-  free_wire(display,wp); return;} else {wp->init_bits++;}
+  free_wire_screen(display,wp); return;} else {wp->init_bits++;}
 
 #define COLORS 4
 #define MINWIRES 32
@@ -205,7 +205,7 @@ positionOfNeighbor(circuitstruct * wp, int dir, int *pcol, int *prow)
 {
 	int         col = *pcol, row = *prow;
 
-	/* NO WRAPING */
+	/* NO WRAPPING */
 
 	if (wp->polygon == 4 || wp->polygon == 6) {
 		switch (dir) {
@@ -931,10 +931,13 @@ free_list(circuitstruct * wp)
 }
 
 static void
-free_wire(Display *display, circuitstruct *wp)
+free_wire_screen(Display *display, circuitstruct *wp)
 {
 	int         shade;
 
+	if (wp == NULL) {
+		return;
+	}
 	for (shade = 0; shade < wp->init_bits; shade++)
 		XFreePixmap(display, wp->pixmaps[shade]);
 	wp->init_bits = 0;
@@ -951,22 +954,10 @@ free_wire(Display *display, circuitstruct *wp)
 		wp->newcells = (unsigned char *) NULL;
 	}
 	free_list(wp);
+	wp = NULL;
 }
 
-void
-release_wire(ModeInfo * mi)
-{
-	if (circuits != NULL) {
-		int         screen;
-
-		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_wire(MI_DISPLAY(mi), &circuits[screen]);
-		free(circuits);
-		circuits = (circuitstruct *) NULL;
-	}
-}
-
-void
+ENTRYPOINT void
 init_wire(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
@@ -975,11 +966,7 @@ init_wire(ModeInfo * mi)
 	circuitstruct *wp;
 	XGCValues   gcv;
 
-	if (circuits == NULL) {
-		if ((circuits = (circuitstruct *) calloc(MI_NUM_SCREENS(mi),
-					    sizeof (circuitstruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, circuits);
 	wp = &circuits[MI_SCREEN(mi)];
 
 	wp->redrawing = 0;
@@ -989,7 +976,7 @@ init_wire(ModeInfo * mi)
 			gcv.fill_style = FillOpaqueStippled;
 			if ((wp->stippledGC = XCreateGC(display, window, GCFillStyle,
 					&gcv)) == None) {
-				free_wire(display, wp);
+				free_wire_screen(display, wp);
 				return;
 			}
 		}
@@ -1170,7 +1157,7 @@ init_wire(ModeInfo * mi)
 	}
 	if ((wp->oldcells = (unsigned char *) calloc(wp->bncols * wp->bnrows,
 			sizeof (unsigned char))) == NULL) {
-		free_wire(display, wp);
+		free_wire_screen(display, wp);
 		return;
 	}
 
@@ -1180,7 +1167,7 @@ init_wire(ModeInfo * mi)
 	}
 	if ((wp->newcells = (unsigned char *) calloc(wp->bncols * wp->bnrows,
 			sizeof (unsigned char))) == NULL) {
-		free_wire(display, wp);
+		free_wire_screen(display, wp);
 		return;
 	}
 
@@ -1196,7 +1183,7 @@ init_wire(ModeInfo * mi)
 	create_path(wp, n);
 }
 
-void
+ENTRYPOINT void
 draw_wire(ModeInfo * mi)
 {
 	int         offset, i, j, found = 0;
@@ -1221,7 +1208,7 @@ draw_wire(ModeInfo * mi)
 				found = 1;
 				*z = *znew;
 				if (!addtolist(mi, i - 2, j - 2, *znew - 1)) {
-					free_wire(MI_DISPLAY(mi), wp);
+					free_wire_screen(MI_DISPLAY(mi), wp);
 					return;
 				}
 			}
@@ -1229,7 +1216,7 @@ draw_wire(ModeInfo * mi)
 	}
 	for (i = 0; i < COLORS - 1; i++)
 		if (!draw_state(mi, i)) {
-			free_wire(MI_DISPLAY(mi), wp);
+			free_wire_screen(MI_DISPLAY(mi), wp);
 			return;
 		}
 	if (++wp->generation > MI_CYCLES(mi) || !found) {
@@ -1252,6 +1239,20 @@ draw_wire(ModeInfo * mi)
 	}
 }
 
+ENTRYPOINT void
+release_wire(ModeInfo * mi)
+{
+	if (circuits != NULL) {
+		int         screen;
+
+		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
+			free_wire_screen(MI_DISPLAY(mi), &circuits[screen]);
+		free(circuits);
+		circuits = (circuitstruct *) NULL;
+	}
+}
+
+#ifndef STANDALONE
 void
 refresh_wire(ModeInfo * mi)
 {
@@ -1265,5 +1266,8 @@ refresh_wire(ModeInfo * mi)
 	wp->redrawing = 1;
 	wp->redrawpos = 2 * wp->ncols + 2;
 }
+#endif
+
+XSCREENSAVER_MODULE ("Wire", wire)
 
 #endif /* MODE_wire */
