@@ -34,8 +34,10 @@ static const char sccsid[] = "@(#)option.c	4.00 97/01/01 xlockmore";
 
 #include <stdio.h>
 #include <stdlib.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 #ifdef VMS
-#include <vms_x_fix.h>
 #include <descrip.h>
 #include <lib$routines.h>
 #include <inttypes.h>
@@ -51,9 +53,18 @@ static const char sccsid[] = "@(#)option.c	4.00 97/01/01 xlockmore";
 #include <Xm/PushBG.h>
 #include <Xm/List.h>
 #include <Xm/ToggleBG.h>
-#elif defined(HAVE_XAW3D)
+#else
 #include <X11/StringDefs.h>
 #include <X11/Intrinsic.h>
+#ifdef HAVE_LIB_XAW3DXFT
+#include <X11/Xaw3dxft/Form.h>
+#include <X11/Xaw3dxft/Box.h>
+#include <X11/Xaw3dxft/SimpleMenu.h>
+#include <X11/Xaw3dxft/MenuButton.h>
+#include <X11/Xaw3dxft/SmeBSB.h>
+#include <X11/Xaw3dxft/Command.h>
+#define HAVE_ATHENA 1
+#elif defined(HAVE_LIB_XAW3D)
 #include <X11/Xaw3d/Form.h>
 #include <X11/Xaw3d/Box.h>
 #include <X11/Xaw3d/SimpleMenu.h>
@@ -61,9 +72,23 @@ static const char sccsid[] = "@(#)option.c	4.00 97/01/01 xlockmore";
 #include <X11/Xaw3d/SmeBSB.h>
 #include <X11/Xaw3d/Command.h>
 #define HAVE_ATHENA 1
-#elif defined(HAVE_ATHENA)
-#include <X11/StringDefs.h>
-#include <X11/Intrinsic.h>
+#elif defined(HAVE_LIB_NEXTAW)
+#include <X11/neXtaw/Form.h>
+#include <X11/neXtaw/Box.h>
+#include <X11/neXtaw/SimpleMenu.h>
+#include <X11/neXtaw/MenuButton.h>
+#include <X11/neXtaw/SmeBSB.h>
+#include <X11/neXtaw/Command.h>
+#define HAVE_ATHENA 1
+#elif defined(HAVE_LIB_XAWPLUS)
+#include <X11/XawPlus/Form.h>
+#include <X11/XawPlus/Box.h>
+#include <X11/XawPlus/SimpleMenu.h>
+#include <X11/XawPlus/MenuButton.h>
+#include <X11/XawPlus/SmeBSB.h>
+#include <X11/XawPlus/Command.h>
+#define HAVE_ATHENA 1
+#elif defined(HAVE_ATHENA) /* HAVE_LIB_XAW */
 #include <X11/Xaw/Form.h>
 #include <X11/Xaw/Box.h>
 #include <X11/Xaw/SimpleMenu.h>
@@ -71,6 +96,7 @@ static const char sccsid[] = "@(#)option.c	4.00 97/01/01 xlockmore";
 #include <X11/Xaw/SmeBSB.h>
 #include <X11/Xaw/Command.h>
 #endif
+#endif
 
 #include "option.h"
 #ifdef HAVE_ATHENA
